/**
 * @file	Clockconfig.c
 * @author	Robert Steigemann
 * @date	15 January 2017
 * @brief	Timer and clock configuration
 *
 * @license creative commons license CC BY-NC 4.0 http://creativecommons.org/licenses/by-nc/4.0/
 */

#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdbool.h>

static volatile uint8_t ctr_1s = 0;
static volatile uint8_t ctr_100ms = 0;
static volatile uint8_t ctr_10ms = 0;


void clk_init(void)
{	
	OSC_CTRL |= (OSC_RC32MEN_bm | OSC_RC32KEN_bm);			// start 32 MHz and 32 kHz oscillator
		
	while(!(OSC_STATUS & OSC_RC32MRDY_bm));					// wait until both oscillators are working stable
	while(!(OSC_STATUS & OSC_RC32KRDY_bm));	
	
	OSC_DFLLCTRL = 0x00;									// use the 32 kHz oscillator for calibration
		
	DFLLRC32M_CTRL = 0x01;									// activate automatic runtime calibration	
		
	CCP = CCP_IOREG_gc;										// save IO and interrupts for four clock cycles 
	
	CLK_CTRL = CLK_SCLKSEL_RC32M_gc;						// choose 32 MHz oscillator as clock source
	
	
	TCD1_CTRLB = TC_WGMODE_NORMAL_gc;						// set waveform-generation-mode: normal counter
	TCD1_INTCTRLA = TC_OVFINTLVL_MED_gc;					// Timer interrupt on, medium level
	TCD1_PERBUF = 1250;										// Timer overflow every 10ms	
	TCD1_CTRLA = TC_CLKSEL_DIV256_gc;						// set prescaler TCD1 to clk/256 = 125kHz	
}


ISR(TCD1_OVF_vect)
{
	if (ctr_1s < UINT8_MAX)
	{
		ctr_1s++;
	}
	if (ctr_100ms < UINT8_MAX)
	{
		ctr_100ms++;
	}
	ctr_10ms=1;	
}


bool timer_1s_tick(void)
{
	if (ctr_1s >= 100)
	{
		ctr_1s = 0;
		return true;
	} 
	else
	{
		return false;
	}	
}

bool timer_100ms_tick(void)
{
	if (ctr_100ms >= 10)
	{
		ctr_100ms = 0;
		return true;
	}
	else
	{
		return false;
	}
}

bool timer_10ms_tick(void)
{
	if (ctr_10ms != 0)
	{
		ctr_10ms = 0;
		return true;
	}
	else
	{
		return false;
	}
}