/**
 * @file	gpio.h
 * @author	Robert Steigemann
 * @date	15 January 2017
 * @brief	Library for GPIO, buttons, and rotary encoder
 *
 * @license creative commons license CC BY-NC 4.0 http://creativecommons.org/licenses/by-nc/4.0/
 */

#ifndef GPIO_H_
#define GPIO_H_

typedef enum gpio_presstime
{
	SHORT,				// short button press
	LONG				// long button press 
} gpio_presstime_t;

typedef enum gpio_button
{
	BUTTON_ROT_ENC = 0,
	BUTTON_1 = 1,		
	BUTTON_2 = 2,
	BUTTON_3 = 3,	
	BUTTON_MAX				
} gpio_button_t;

typedef enum gpio_item
{
	ITEM_BUTTON_ROT_ENC = 0,
	ITEM_BUTTON_1 = 1,
	ITEM_BUTTON_2 = 2,
	ITEM_BUTTON_3 = 3,
	ITEM_STB_SW_1 = 4,
	ITEM_STB_SW_2 = 5,
	ITEM_ENC_A = 6,
	ITEM_ENC_B = 7,
	ITEM_MAX
} gpio_item_t;

// init all the gpio related functions
void gpio_init(void);

// get the logic level (1 = true) of a gpi pin
bool gpio_get(gpio_item_t item);

bool gpio_checkButton(gpio_button_t button, gpio_presstime_t duration);

// execute this function periodically every 10 ms
void gpio_poll(void);

// returns the covered steps (+/-) since last check
int8_t gpio_getRotEnc(void);

bool gpio_iron_taken(void);
bool gpio_iron_inserted(void);


#endif /* GPIO_H_ */