/**
 * @file	pwm.c
 * @author	Robert Steigemann
 * @date	15 January 2017
 * @brief	1 Hz PWM for power control
 *
 * @license creative commons license CC BY-NC 4.0 http://creativecommons.org/licenses/by-nc/4.0/
 */

#include <avr/io.h>

void pwm_init(void)
{
	TCC0_CTRLB = (1<<4) |TC_WGMODE_DS_T_gc;			// Dual Slope PWM and enable OC0A output
	TCC0_PERBUF = F_CPU / ( 2 * 1024 );				// PER = F_CPU / (2 * prescaler * f) | f = 1 Hz
	TCC0_CCABUF = 0;								// PWM duty-cycle is 0 % after init
	TCC0_CTRLA = TC_CLKSEL_DIV1024_gc;				// start timer with prescaler = 1024
}

void pwm_set_power(uint8_t percent)
{
	if (percent > 100)
	{
		percent = 100;
	}	
	TCC0_CCABUF = (uint16_t)( ( (uint32_t)percent * (uint32_t)TCC0_PERBUF ) / 100UL );	
}